==> aws-cdk.aws-servicecatalogappregistry-alpha-2.45.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_servicecatalogappregistry_alpha_IApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_Application(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_IAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociatorProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociator(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_SharePermission(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ShareOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.roles))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IRole(p.roles);
        if (!visitedObjects.has(p.users))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IUser(p.users);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_servicecatalogappregistry_alpha_IApplication, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_alpha_Application, _aws_cdk_aws_servicecatalogappregistry_alpha_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociatorProps, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociator, _aws_cdk_aws_servicecatalogappregistry_alpha_SharePermission, _aws_cdk_aws_servicecatalogappregistry_alpha_ShareOptions };

==> aws-cdk.aws-servicecatalogappregistry-alpha-2.47.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_servicecatalogappregistry_alpha_IApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_Application(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_IAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociatorProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociator(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_SharePermission(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_alpha_ShareOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.roles != null)
            for (const o of p.roles)
                if (!visitedObjects.has(o))
                    require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IRole(o);
        if (p.users != null)
            for (const o of p.users)
                if (!visitedObjects.has(o))
                    require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_iam_IUser(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_servicecatalogappregistry_alpha_IApplication, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_alpha_Application, _aws_cdk_aws_servicecatalogappregistry_alpha_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_alpha_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociatorProps, _aws_cdk_aws_servicecatalogappregistry_alpha_ApplicationAssociator, _aws_cdk_aws_servicecatalogappregistry_alpha_SharePermission, _aws_cdk_aws_servicecatalogappregistry_alpha_ShareOptions };
